==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/math1/maplib/mpfcyl.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     MAP PROJECTION (LONGITUDE-LATITUDE)              93/02/20 S.SAKAI */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int mpfcyl_0_(int n__, real *xlon, real *ylat, real *x, real 
	*y)
{
    static real pi, rna;
    extern real rfpi_(void);
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
    extern real xmplon_(real *);

    switch(n__) {
	case 1: goto L_mpicyl;
	}

    pi = rfpi_();
    *x = xmplon_(xlon);
    *y = *ylat;
    if (*y > pi / 2) {
	*y = pi / 2;
    }
    if (*y < -pi / 2) {
	*y = -pi / 2;
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_mpicyl:
    pi = rfpi_();
    *xlon = *x;
    *ylat = *y;
    if (abs(*xlon) <= pi && abs(*ylat) <= pi / 2) {
	return 0;
    }
    glrget_("RUNDEF", &rna, (ftnlen)6);
    *xlon = rna;
    *ylat = rna;
    return 0;
} /* mpfcyl_ */

/* Subroutine */ int mpfcyl_(real *xlon, real *ylat, real *x, real *y)
{
    return mpfcyl_0_(0, xlon, ylat, x, y);
    }

/* Subroutine */ int mpicyl_(real *x, real *y, real *xlon, real *ylat)
{
    return mpfcyl_0_(1, xlon, ylat, x, y);
    }

==> dcl-c_5.3-20050523-1.tar.gz: dcl-c-5.3-20050523/src/math1/maplib/mpfcyl.c <==
/* src/math1/maplib/mpfcyl.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     MAP PROJECTION (LONGITUDE-LATITUDE)              93/02/20 S.SAKAI */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int mpfcyl_0_(int n__, real *xlon, real *ylat, real *x, real 
	*y)
{
    static real pi, rna;
    extern doublereal rfpi_(void);
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
    extern doublereal xmplon_(real *);

    switch(n__) {
	case 1: goto L_mpicyl;
	}

    pi = rfpi_();
    *x = xmplon_(xlon);
    *y = *ylat;
    if (*y > pi / 2) {
	*y = pi / 2;
    }
    if (*y < -pi / 2) {
	*y = -pi / 2;
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_mpicyl:
    pi = rfpi_();
    *xlon = *x;
    *ylat = *y;
    if (dabs(*xlon) <= pi && dabs(*ylat) <= pi / 2) {
	return 0;
    }
    glrget_("RUNDEF", &rna, (ftnlen)6);
    *xlon = rna;
    *ylat = rna;
    return 0;
} /* mpfcyl_ */

/* Subroutine */ int mpfcyl_(real *xlon, real *ylat, real *x, real *y)
{
    return mpfcyl_0_(0, xlon, ylat, x, y);
    }

/* Subroutine */ int mpicyl_(real *x, real *y, real *xlon, real *ylat)
{
    return mpfcyl_0_(1, xlon, ylat, x, y);
    }
